@@ -1,8 +1,10 @@
 package Email::Mailer;
 # ABSTRACT: Multi-purpose emailer for HTML, auto-text, attachments, and templates
 
+use 5.014;
 use strict;
 use warnings;
+
 use HTML::FormatText;
 use HTML::TreeBuilder;
 use IO::All 'io';
@@ -10,7 +12,7 @@ use Email::MIME;
 use Email::MIME::CreateHTML;
 use Email::Sender::Simple 'sendmail';
 
-our $VERSION = '1.02'; # VERSION
+our $VERSION = '1.03'; # VERSION
 
 sub new {
     my $self = shift;
@@ -54,7 +56,11 @@ sub send {
 
         # create a headers hashref (delete things from a data copy that known to not be headers)
         my $headers = [
-            map { ucfirst($_) => $mail->{$_} }
+            map {
+                $mail->{$_} = join( ',', @{ $mail->{$_} }        ) if ( ref $mail->{$_} eq 'ARRAY' );
+                $mail->{$_} = join( ',', values %{ $mail->{$_} } ) if ( ref $mail->{$_} eq 'HASH'  );
+                ucfirst($_) => $mail->{$_};
+            }
             grep { not /^(?:html|text|embed|attachments|process|data|transport)$/i }
             sort keys %$mail
         ];
@@ -136,7 +142,7 @@ Email::Mailer - Multi-purpose emailer for HTML, auto-text, attachments, and temp
 
 =head1 VERSION
 
-version 1.02
+version 1.03
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Email-Mailer.svg)](https://travis-ci.org/gryphonshafer/Email-Mailer)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Email-Mailer/badge.png)](https://coveralls.io/r/gryphonshafer/Email-Mailer)
